@@ -1,5 +1,9 @@
-from .computation_engine import apply, join, summarize, Engine, output, DelayedException
+from .computation_engine import (apply, join, summarize,
+                                 apply_local, join_local, summarize_local,
+                                 Engine, output, DelayedException)
+
 from .fs_cache import CacheBuilder, LocalCacheBuilder
+
 from .std_logger import get_logger
 
 # DO NOT TOUCH THE FOLLOWING LINE:
