@@ -308,9 +308,9 @@ class JoinComputation(Computation):
 
 class SummarizeComputation(Computation):
 
-    def __init__(self, f, inputs):
+    def __init__(self, f, inputs, run_local=False):
         assert len(inputs) == 1, "summarize computations only accept one input stream"
-        super(SummarizeComputation, self).__init__(f, inputs)
+        super(SummarizeComputation, self).__init__(f, inputs, run_local)
 
     def compute_size(self):
         return 1
